@@ -1,6 +1,6 @@
 package UvT::Email::Template;
 
-# $Id: Template.pm 39379 2013-05-07 07:54:44Z wsl $
+# $Id: Template.pm 39390 2013-05-08 15:14:00Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/uvt-email-template/lib/UvT/Email/Template.pm $
 
 # formatteer een XML-bericht tot een multipart/alternative MIME
@@ -24,7 +24,7 @@ use Scalar::Util qw(weaken reftype refaddr);
 	my %array_each;
 	my %array_each_i;
 
-	sub array_each(+) {
+	sub array_each(\@) {
 		my $arr = shift;
 		confess "Not an array or arrayref"
 			unless reftype($arr) eq 'ARRAY';
@@ -327,8 +327,8 @@ sub build_table {
 			my $text = $self->nodes_to_par($col);
 			$text =~ s/\s+$//s;
 			push @cells, $text;
-			my $h = split(/\n/, $text);
-			$height = $h if $height < $h;
+			my @h = split(/\n/, $text);
+			$height = @h if $height < @h;
 		}
 		my $rowres = "│\n"x$height;
 		while(my ($i, $cell) = array_each(@cells)) {
